Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(984)

Unified Diff: runtime/vm/flow_graph_optimizer.cc

Issue 15145002: Unbox phis with Float32x4 or Uint32x4 type (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 7 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | tests/lib/typed_data/float32x4_unbox_phi_test.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/flow_graph_optimizer.cc
diff --git a/runtime/vm/flow_graph_optimizer.cc b/runtime/vm/flow_graph_optimizer.cc
index cfd7790f8705ff5bac798e5f192530ab5d73205d..b63e21ecc16fd5029eb20eb4edb75111c9ff6f90 100644
--- a/runtime/vm/flow_graph_optimizer.cc
+++ b/runtime/vm/flow_graph_optimizer.cc
@@ -422,7 +422,8 @@ void FlowGraphOptimizer::InsertConversionsFor(Definition* def) {
void FlowGraphOptimizer::SelectRepresentations() {
// Convervatively unbox all phis that were proven to be of type Double.
for (intptr_t i = 0; i < block_order_.length(); ++i) {
JoinEntryInstr* join_entry = block_order_[i]->AsJoinEntry();
if (join_entry != NULL) {
@@ -431,6 +432,10 @@ void FlowGraphOptimizer::SelectRepresentations() {
ASSERT(phi != NULL);
if (phi->Type()->ToCid() == kDoubleCid) {
phi->set_representation(kUnboxedDouble);
+ } else if (phi->Type()->ToCid() == kFloat32x4Cid) {
+ phi->set_representation(kUnboxedFloat32x4);
+ } else if (phi->Type()->ToCid() == kUint32x4Cid) {
+ phi->set_representation(kUnboxedUint32x4);
}
}
}
@@ -422,7 +422,8 @@ void FlowGraphOptimizer::InsertConversionsFor(Definition* def) {
void FlowGraphOptimizer::SelectRepresentations() {
- // Convervatively unbox all phis that were proven to be of type Double.
+ // Convervatively unbox all phis that were proven to be of Double,
+ // Float32x4, or Uint32x4.
for (intptr_t i = 0; i < block_order_.length(); ++i) {
JoinEntryInstr* join_entry = block_order_[i]->AsJoinEntry();
« no previous file with comments | « no previous file | tests/lib/typed_data/float32x4_unbox_phi_test.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698